@@ -3,23 +3,27 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "Also available in": "Διαθέσιμο και στα",
+    "Also available in:": "Διαθέσιμο και στα:",
     "Archive": "Αρχείο",
-    "Categories": "",
+    "Categories": "Κατηγορίες",
     "LANGUAGE": "Ελληνικά",
+    "More posts about %s": "Περισσότερες αναρτήσεις για %s",
     "More posts about": "Περισσότερες αναρτήσεις για",
     "Newer posts": "Νεότερες αναρτήσεις",
     "Next post": "Επόμενη ανάρτηση",
     "Older posts": "Παλαιότερες αναρτήσεις",
     "Original site": "Ιστοσελίδα αρχικής ανάρτησης",
     "Posted": "Αναρτήθηκε",
+    "Posted:": "Αναρτήθηκε:",
     "Posts about %s": "Αναρτήσεις για %s",
     "Posts for year %s": "Αναρτήσεις για το έτος %s",
-    "Posts for {month} {year}": "",
+    "Posts for {month} {year}": "Αναρτήσεις για τον {month} του {year}",
     "Previous post": "Προηγούμενη ανάρτηση",
     "Read in English": "Διαβάστε στα Ελληνικά",
     "Read more": "Διαβάστε περισσότερα",
     "Source": "Πηγαίος κώδικας",
-    "Tags and Categories": "",
+    "Tags and Categories": "Ετικέτες και κατηγορίες",
     "Tags": "Ετικέτες",
-    "old posts page %d": "σελίδα παλαιότερων αναρτήσεων %d",
+    "old posts, page %d": "σελίδα παλαιότερων αναρτήσεων %d",
+    "page %d": "σελίδα %d",
 }
