@@ -3,15 +3,18 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "Also available in": "Also available in",
+    "Also available in:": "Also available in:",
     "Archive": "Archive",
     "Categories": "Categories",
     "LANGUAGE": "English",
+    "More posts about %s": "More posts about %s",
     "More posts about": "More posts about",
     "Newer posts": "Newer posts",
     "Next post": "Next post",
     "Older posts": "Older posts",
     "Original site": "Original site",
     "Posted": "Posted",
+    "Posted:": "Posted:",
     "Posts about %s": "Posts about %s",
     "Posts for year %s": "Posts for year %s",
     "Posts for {month} {year}": "Posts for {month} {year}",
@@ -21,5 +24,6 @@ MESSAGES = {
     "Source": "Source",
     "Tags and Categories": "Tags and Categories",
     "Tags": "Tags",
-    "old posts page %d": "old posts page %d",
+    "old posts, page %d": "old posts, page %d",
+    "page %d": "page %d",
 }
