@@ -3,15 +3,18 @@ from __future__ import unicode_literals
 
 MESSAGES = {
     "Also available in": "Anche disponibile in",
+    "Also available in:": "Anche disponibile in:",
     "Archive": "Archivio",
-    "Categories": "",
+    "Categories": "Categorie",
     "LANGUAGE": "Italiano",
+    "More posts about %s": "Altri articoli collegati %s",
     "More posts about": "Altri articoli collegati",
     "Newer posts": "Articoli recenti",
     "Next post": "Articolo successivo",
     "Older posts": "Articoli precedenti",
     "Original site": "Sito originale",
     "Posted": "Pubblicato",
+    "Posted:": "Pubblicato:",
     "Posts about %s": "Articoli su %s",
     "Posts for year %s": "Articoli per l'anno %s",
     "Posts for {month} {year}": "Articoli per {month} {year}",
@@ -19,7 +22,8 @@ MESSAGES = {
     "Read in English": "Leggi in italiano",
     "Read more": "Espandi",
     "Source": "Sorgente",
-    "Tags and Categories": "",
+    "Tags and Categories": "Tags e Categorie",
     "Tags": "Tags",
-    "old posts page %d": "pagina dei vecchi articoli %d",
+    "old posts, page %d": "pagina dei vecchi articoli %d",
+    "page %d": "pagina %d",
 }
