@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -42,6 +42,12 @@ from doit.cmd_base import Command as DoitCommand
 
 from .utils import LOGGER, first_line
 
+try:
+    # ordereddict does not exist in py2.6
+    from collections import OrderedDict
+except ImportError:
+    OrderedDict = None  # NOQA
+
 
 class BasePlugin(IPlugin):
     """Base plugin class."""
@@ -157,6 +163,11 @@ class TemplateSystem(BasePlugin):
         """
         raise NotImplementedError()
 
+    def render_template_to_string(self, template, context):
+        """ Renders template to a string using context. """
+
+        raise NotImplementedError()
+
 
 class TaskMultiplier(BasePlugin):
     """Plugins that take a task and return *more* tasks."""
@@ -173,14 +184,22 @@ class PageCompiler(BasePlugin):
     """Plugins that compile text files into HTML."""
 
     name = "dummy compiler"
-    default_metadata = {
-        'title': '',
-        'slug': '',
-        'date': '',
-        'tags': '',
-        'link': '',
-        'description': '',
-    }
+    demote_headers = False
+    if OrderedDict is not None:
+        default_metadata = OrderedDict()
+    else:
+        # Graceful fallback.  We could use a backport, but it is
+        # not going to change anything, other than a bit uglier
+        # and nonsensical layout.  Not enough to care.
+        default_metadata = {}
+
+    default_metadata['title'] = ''
+    default_metadata['slug'] = ''
+    default_metadata['date'] = ''
+    default_metadata['tags'] = ''
+    default_metadata['link'] = ''
+    default_metadata['description'] = ''
+    default_metadata['type'] = 'text'
 
     def compile_html(self, source, dest, is_two_file=False):
         """Compile the source, save it on dest."""
