@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -30,10 +30,12 @@ import datetime
 import os
 import sys
 
+from blinker import signal
+
 from nikola.plugin_categories import Command
 from nikola import utils
 
-LOGGER = utils.get_logger('new_post')
+LOGGER = utils.get_logger('new_post', utils.STDERR_HANDLER)
 
 
 def filter_post_pages(compiler, is_post, compilers, post_pages):
@@ -184,7 +186,6 @@ class CommandNewPost(Command):
 
     def _execute(self, options, args):
         """Create a new post or page."""
-
         compiler_names = [p.name for p in
                           self.site.plugin_manager.getPluginsOfCategory(
                               "PageCompiler")]
@@ -276,10 +277,15 @@ class CommandNewPost(Command):
             txt_path, onefile, title=title,
             slug=slug, date=date, tags=tags, **metadata)
 
+        event = dict(path=txt_path)
+
         if not onefile:  # write metadata file
             with codecs.open(meta_path, "wb+", "utf8") as fd:
                 fd.write('\n'.join(data))
             with codecs.open(txt_path, "wb+", "utf8") as fd:
                 fd.write("Write your post here.")
             LOGGER.notice("Your post's metadata is at: {0}".format(meta_path))
+            event['meta_path'] = meta_path
         LOGGER.notice("Your post's text is at: {0}".format(txt_path))
+
+        signal('new_post').send(self, **event)
