@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -36,8 +36,6 @@ except ImportError:
 from nikola.plugin_categories import Command
 from nikola.utils import get_logger
 
-LOGGER = get_logger('serve')
-
 
 class CommandBuild(Command):
     """Start test server."""
@@ -45,6 +43,7 @@ class CommandBuild(Command):
     name = "serve"
     doc_usage = "[options]"
     doc_purpose = "start the test webserver"
+    logger = None
 
     cmd_options = (
         {
@@ -67,15 +66,16 @@ class CommandBuild(Command):
 
     def _execute(self, options, args):
         """Start test server."""
+        self.logger = get_logger('serve', self.site.loghandlers)
         out_dir = self.site.config['OUTPUT_FOLDER']
         if not os.path.isdir(out_dir):
-            LOGGER.error("Missing '{0}' folder?".format(out_dir))
+            self.logger.error("Missing '{0}' folder?".format(out_dir))
         else:
             os.chdir(out_dir)
             httpd = HTTPServer((options['address'], options['port']),
                                OurHTTPRequestHandler)
             sa = httpd.socket.getsockname()
-            LOGGER.notice("Serving HTTP on {0} port {1} ...".format(*sa))
+            self.logger.notice("Serving HTTP on {0} port {1} ...".format(*sa))
             httpd.serve_forever()
 
 
