@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -30,6 +30,7 @@ from __future__ import unicode_literals
 
 import codecs
 import os
+import re
 
 try:
     from markdown import markdown
@@ -49,6 +50,12 @@ except ImportError:
     gist_extension = None
     podcast_extension = None
 
+
+try:
+    from collections import OrderedDict
+except ImportError:
+    OrderedDict = None  # NOQA
+
 from nikola.plugin_categories import PageCompiler
 from nikola.utils import makedirs, req_missing
 
@@ -57,6 +64,7 @@ class CompileMarkdown(PageCompiler):
     """Compile markdown into HTML."""
 
     name = "markdown"
+    demote_headers = True
     extensions = [gist_extension, nikola_extension, podcast_extension]
     site = None
 
@@ -69,12 +77,15 @@ class CompileMarkdown(PageCompiler):
             with codecs.open(source, "r", "utf8") as in_file:
                 data = in_file.read()
             if not is_two_file:
-                data = data.split('\n\n', 1)[-1]
+                data = re.split('(\n\n|\r\n\r\n)', data, maxsplit=1)[-1]
             output = markdown(data, self.extensions)
             out_file.write(output)
 
     def create_post(self, path, onefile=False, **kw):
-        metadata = {}
+        if OrderedDict is not None:
+            metadata = OrderedDict()
+        else:
+            metadata = {}
         metadata.update(self.default_metadata)
         metadata.update(kw)
         makedirs(os.path.dirname(path))
