@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2013 Michael Rabbitt.
+# Copyright © 2013 Michael Rabbitt.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a
 # copy of this software and associated documentation files (the
@@ -121,9 +121,9 @@ from markdown.extensions import Extension
 from markdown.inlinepatterns import Pattern
 from markdown.util import AtomicString
 from markdown.util import etree
-from nikola.utils import get_logger, req_missing
+from nikola.utils import get_logger, req_missing, STDERR_HANDLER
 
-LOGGER = get_logger('compile_markdown.mdx_gist')
+LOGGER = get_logger('compile_markdown.mdx_gist', STDERR_HANDLER)
 
 try:
     import requests
