@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2013 Chris Lee
+# Copyright © 2013-2014 Chris Lee and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -37,6 +37,11 @@ try:
 except ImportError:
     misaka = None  # NOQA
     nikola_extension = None
+try:
+    from collections import OrderedDict
+except ImportError:
+    OrderedDict = None  # NOQA
+
     gist_extension = None
     podcast_extension = None
 
@@ -44,13 +49,14 @@ from nikola.plugin_categories import PageCompiler
 from nikola.utils import makedirs, req_missing
 
 
-class CompileMarkdown(PageCompiler):
-    """Compile markdown into HTML."""
+class CompileMisaka(PageCompiler):
+    """Compile Misaka into HTML."""
 
-    name = "markdown"
+    name = "misaka"
+    demote_headers = True
 
     def __init__(self, *args, **kwargs):
-        super(CompileMarkdown, self).__init__(*args, **kwargs)
+        super(CompileMisaka, self).__init__(*args, **kwargs)
         if misaka is not None:
             self.ext = misaka.EXT_FENCED_CODE | misaka.EXT_STRIKETHROUGH | \
                 misaka.EXT_AUTOLINK | misaka.EXT_NO_INTRA_EMPHASIS
@@ -68,7 +74,10 @@ class CompileMarkdown(PageCompiler):
             out_file.write(output)
 
     def create_post(self, path, onefile=False, **kw):
-        metadata = {}
+        if OrderedDict is not None:
+            metadata = OrderedDict()
+        else:
+            metadata = {}
         metadata.update(self.default_metadata)
         metadata.update(kw)
         makedirs(os.path.dirname(path))
