@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -36,7 +36,7 @@ import json
 
 
 from nikola.plugin_categories import RestExtension
-from nikola import utils
+from nikola.utils import req_missing
 
 
 class Plugin(RestExtension):
@@ -96,11 +96,7 @@ class Vimeo(Directive):
     def check_modules(self):
         msg = None
         if requests is None:
-            msg = (
-                "To use the Vimeo directive you need to install "
-                "the requests module.\n"
-            )
-            utils.LOGGER.warn(msg)
+            msg = req_missing(['requests'], 'use the vimeo directive', optional=True)
             return [nodes.raw('', '<div class="text-error">{0}</div>'.format(msg), format='html')]
         return None
 
