@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -28,6 +28,7 @@
 
 import codecs
 import os
+import re
 
 try:
     from textile import textile
@@ -37,11 +38,17 @@ except ImportError:
 from nikola.plugin_categories import PageCompiler
 from nikola.utils import makedirs, req_missing
 
+try:
+    from collections import OrderedDict
+except ImportError:
+    OrderedDict = None  # NOQA
+
 
 class CompileTextile(PageCompiler):
     """Compile textile into HTML."""
 
     name = "textile"
+    demote_headers = True
 
     def compile_html(self, source, dest, is_two_file=True):
         if textile is None:
@@ -51,12 +58,15 @@ class CompileTextile(PageCompiler):
             with codecs.open(source, "r", "utf8") as in_file:
                 data = in_file.read()
             if not is_two_file:
-                data = data.split('\n\n', 1)[-1]
+                data = re.split('(\n\n|\r\n\r\n)', data, maxsplit=1)[-1]
             output = textile(data, head_offset=1)
             out_file.write(output)
 
     def create_post(self, path, onefile=False, **kw):
-        metadata = {}
+        if OrderedDict is not None:
+            metadata = OrderedDict()
+        else:
+            metadata = {}
         metadata.update(self.default_metadata)
         metadata.update(kw)
         makedirs(os.path.dirname(path))
