@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -41,6 +41,10 @@ class Listings(Task):
 
     name = "render_listings"
 
+    def set_site(self, site):
+        site.register_path_handler('listing', self.listing_path)
+        return super(Listings, self).set_site(site)
+
     def gen_tasks(self):
         """Render pretty code listings."""
         kw = {
@@ -126,3 +130,7 @@ class Listings(Task):
                         self.site.GLOBAL_CONTEXT)],
                     'clean': True,
                 }
+
+    def listing_path(self, name, lang):
+        return [_f for _f in [self.site.config['LISTINGS_FOLDER'], name +
+                              '.html'] if _f]
