@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -33,10 +33,13 @@ import tempfile
 
 from mako import util, lexer
 from mako.lookup import TemplateLookup
+from mako.template import Template
 from markupsafe import Markup  # It's ok, Mako requires it
 
 from nikola.plugin_categories import TemplateSystem
-from nikola.utils import makedirs, get_logger
+from nikola.utils import makedirs, get_logger, STDERR_HANDLER
+
+LOGGER = get_logger('mako', STDERR_HANDLER)
 
 
 class MakoTemplates(TemplateSystem):
@@ -69,8 +72,7 @@ class MakoTemplates(TemplateSystem):
                 os.path.abspath(cache_dir).decode('ascii')
             except UnicodeEncodeError:
                 cache_dir = tempfile.mkdtemp()
-                self.logger = get_logger('mako', self.site.loghandlers)
-                self.logger.warning('Because of a Mako bug, setting cache_dir to {0}'.format(cache_dir))
+                LOGGER.warning('Because of a Mako bug, setting cache_dir to {0}'.format(cache_dir))
 
         if os.path.exists(cache_dir):
             shutil.rmtree(cache_dir)
@@ -90,9 +92,14 @@ class MakoTemplates(TemplateSystem):
                 output.write(data)
         return data
 
+    def render_template_to_string(self, template, context):
+        """ Render template to a string using context. """
+
+        return Template(template).render(**context)
+
     def template_deps(self, template_name):
         """Returns filenames which are dependencies for a template."""
-        # We can cache here because depedencies should
+        # We can cache here because dependencies should
         # not change between runs
         if self.cache.get(template_name, None) is None:
             template = self.lookup.get_template(template_name)
