@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright © 2012-2013 Roberto Alsina and others.
+# Copyright © 2012-2014 Roberto Alsina and others.
 
 # Permission is hereby granted, free of charge, to any
 # person obtaining a copy of this software and associated
@@ -28,9 +28,11 @@
 
 from __future__ import print_function, unicode_literals
 from collections import defaultdict, Callable
+import calendar
 import datetime
 import hashlib
 import locale
+import logging
 import os
 import re
 import codecs
@@ -48,23 +50,36 @@ import logbook
 from logbook.more import ExceptionHandler
 import pytz
 
+from . import DEBUG
+
 
 class ApplicationWarning(Exception):
     pass
 
 
-def get_logger(name, level=logbook.NOTICE):
-    """Get a logger for a plugin."""
+def get_logger(name, handlers):
+    """Get a logger with handlers attached."""
     l = logbook.Logger(name)
-    l.handlers.append(logbook.StderrHandler(
-        level=level,
-        format_string=u'[{record.time:%Y-%m-%dT%H:%M:%SZ}] {record.level_name}: {record.channel}: {record.message}'
-    ))
+    for h in handlers:
+        if isinstance(h, list):
+            l.handlers += h
+        else:
+            l.handlers.append(h)
     return l
 
-LOGGER = get_logger('Nikola')
+
+STDERR_HANDLER = [logbook.StderrHandler(
+    level=logbook.NOTICE if not DEBUG else logbook.DEBUG,
+    format_string=u'[{record.time:%Y-%m-%dT%H:%M:%SZ}] {record.level_name}: {record.channel}: {record.message}'
+)]
+LOGGER = get_logger('Nikola', STDERR_HANDLER)
 STRICT_HANDLER = ExceptionHandler(ApplicationWarning, level='WARNING')
 
+if DEBUG:
+    logging.basicConfig(level=logging.DEBUG)
+else:
+    logging.basicConfig(level=logging.WARNING)
+
 
 def req_missing(names, purpose, python=True, optional=False):
     """Log that we are missing some requirements."""
@@ -88,7 +103,8 @@ def req_missing(names, purpose, python=True, optional=False):
         LOGGER.warn(msg)
     else:
         LOGGER.error(msg)
-        raise Exception('Missing dependencies: {0}'.format(', '.join(names)))
+        LOGGER.error('Exiting due to missing dependencies.')
+        sys.exit(5)
 
     return msg
 
@@ -114,7 +130,8 @@ __all__ = ['get_theme_path', 'get_theme_chain', 'load_messages', 'copy_tree',
            'to_datetime', 'apply_filters', 'config_changed', 'get_crumbs',
            'get_tzname', 'get_asset_path', '_reload', 'unicode_str', 'bytes_str',
            'unichr', 'Functionary', 'LocaleBorg', 'sys_encode', 'sys_decode',
-           'makedirs', 'get_parent_theme_name']
+           'makedirs', 'get_parent_theme_name', 'ExtendedRSS2', 'demote_headers',
+           'get_translation_candidate']
 
 
 ENCODING = sys.getfilesystemencoding() or sys.stdin.encoding
@@ -136,7 +153,7 @@ def sys_decode(thing):
 
 def makedirs(path):
     """Create a folder."""
-    if os.path.isdir(path):
+    if not path or os.path.isdir(path):
         return
     if os.path.exists(path):
         raise OSError('Path {0} already exists and is not a folder.')
@@ -151,28 +168,12 @@ class Functionary(defaultdict):
         super(Functionary, self).__init__(default)
         self.default_lang = default_lang
 
-    def current_lang(self):
-        """Guess the current language from locale or default."""
-        lang = locale.getlocale()[0]
-        if lang is None:
-            # for python 2.x, see issues 12699 and 6203 in python bugtracker
-            locale.setlocale(locale.LC_ALL, '')
-            lang = locale.getlocale()[0]
-        if lang:
-            if lang in self.keys():
-                return lang
-            lang = lang.split('_')[0]
-            if lang in self.keys():
-                return lang
-        # whatever
-        return self.default_lang
-
     def __call__(self, key, lang=None):
         """When called as a function, take an optional lang
         and return self[lang][key]."""
 
         if lang is None:
-            lang = self.current_lang()
+            lang = LocaleBorg().current_lang
         return self[lang][key]
 
 
@@ -339,21 +340,22 @@ def generic_rss_renderer(lang, title, link, description, timeline, output_path,
             'pubDate': (post.date if post.date.tzinfo is None else
                         post.date.astimezone(pytz.timezone('UTC'))),
             'categories': post._tags.get(lang, []),
+            'author': post.meta('author'),
         }
-        if post.meta('author') is not None:
-            args['author'] = post.meta('author')
-        items.append(rss.RSSItem(**args))
+
+        items.append(ExtendedItem(**args))
     rss_obj = ExtendedRSS2(
         title=title,
         link=link,
         description=description,
         lastBuildDate=datetime.datetime.now(),
         items=items,
-        generator='nikola',
+        generator='Nikola <http://getnikola.com/>',
         language=lang
     )
     rss_obj.self_url = feed_url
     rss_obj.rss_attrs["xmlns:atom"] = "http://www.w3.org/2005/Atom"
+    rss_obj.rss_attrs["xmlns:dc"] = "http://purl.org/dc/elements/1.1/"
     dst_dir = os.path.dirname(output_path)
     makedirs(dst_dir)
     with codecs.open(output_path, "wb+", "utf-8") as rss_file:
@@ -479,7 +481,7 @@ def to_datetime(value, tzinfo=None):
             dt = datetime.datetime.strptime(value, format)
             if tzinfo is None:
                 return dt
-            # Build a localized time by using a given timezone.
+            # Build a localized time by using a given time zone.
             return tzinfo.localize(dt)
         except ValueError:
             pass
@@ -498,7 +500,7 @@ def to_datetime(value, tzinfo=None):
 
 def get_tzname(dt):
     """
-    Give a datetime value, find the name of the timezone
+    Given a datetime value, find the name of the time zone.
     """
     try:
         from dateutil import tz
@@ -557,8 +559,10 @@ def apply_filters(task, filters):
     return task
 
 
-def get_crumbs(path, is_file=False):
+def get_crumbs(path, is_file=False, index_folder=None):
     """Create proper links for a crumb bar.
+    index_folder is used if you want to use title from index file
+    instead of folder name as breadcrumb text.
 
     >>> crumbs = get_crumbs('galleries')
     >>> len(crumbs)
@@ -597,12 +601,22 @@ def get_crumbs(path, is_file=False):
         for i, crumb in enumerate(crumbs[::-1]):
             _path = '/'.join(['..'] * i) or '#'
             _crumbs.append([_path, crumb])
+    if index_folder and hasattr(index_folder, 'parse_index'):
+        folder = path
+        for i, crumb in enumerate(crumbs[::-1]):
+            if folder[-1] == os.sep:
+                folder = folder[:-1]
+            index_post = index_folder.parse_index(folder)
+            folder = folder.replace(crumb, '')
+            if index_post:
+                crumb = index_post.title() or crumb
+            _crumbs[i][1] = crumb
     return list(reversed(_crumbs))
 
 
 def get_asset_path(path, themes, files_folders={'files': ''}):
     """
-    .. versionchanghed:: 6.1.0
+    .. versionchanged:: 6.1.0
 
     Checks which theme provides the path with the given asset,
     and returns the "real", absolute path to the asset.
@@ -631,10 +645,7 @@ def get_asset_path(path, themes, files_folders={'files': ''}):
         if os.path.isfile(candidate):
             return candidate
     for src, rel_dst in files_folders.items():
-        candidate = os.path.join(
-            src,
-            os.path.abspath(path)
-        )
+        candidate = os.path.abspath(os.path.join(src, path))
         if os.path.isfile(candidate):
             return candidate
 
@@ -642,14 +653,107 @@ def get_asset_path(path, themes, files_folders={'files': ''}):
     return None
 
 
-class LocaleBorg:
-    __shared_state = {
-        'current_lang': None
-    }
+class LocaleBorg(object):
+    """
+    Provides locale related services and autoritative current_lang,
+    where current_lang is the last lang for which the locale was set.
+
+    current_lang is meant to be set only by LocaleBorg.set_locale
+
+    python's locale code should not be directly called from code outside of
+    LocaleBorg, they are compatibilty issues with py version and OS support
+    better handled at one central point, LocaleBorg.
+
+    In particular, don't call locale.setlocale outside of LocaleBorg.
+
+    Assumptions:
+        We need locales only for the languages there is a nikola translation.
+        We don't need to support current_lang through nested contexts
+
+    Usage:
+        # early in cmd or test execution
+        LocaleBorg.initialize(...)
+
+        # any time later
+        lang = LocaleBorg().<service>
+
+    Available services:
+        .current_lang : autoritative current_lang , the last seen in set_locale
+        .set_locale(lang) : sets current_lang and sets the locale for lang
+        .get_month_name(month_no, lang) : returns the localized month name
+
+    NOTE: never use locale.getlocale() , it can return values that
+    locale.setlocale will not accept in Windows XP, 7 and pythons 2.6, 2.7, 3.3
+    Examples: "Spanish", "French" can't do the full circle set / get / set
+    That used to break calendar, but now seems is not the case, with month at least
+    """
+    @classmethod
+    def initialize(cls, locales, initial_lang):
+        """
+        locales : dict with lang: locale_n
+            the same keys as in nikola's TRANSLATIONS
+            locale_n a sanitized locale, meaning
+                locale.setlocale(locale.LC_ALL, locale_n) will succeed
+                locale_n expressed in the string form, like "en.utf8"
+        """
+        assert initial_lang is not None and initial_lang in locales
+        cls.reset()
+        cls.locales = locales
+
+        # needed to decode some localized output in py2x
+        encodings = {}
+        for lang in locales:
+            locale.setlocale(locale.LC_ALL, locales[lang])
+            loc, encoding = locale.getlocale()
+            encodings[lang] = encoding
+
+        cls.encodings = encodings
+        cls.__shared_state['current_lang'] = initial_lang
+        cls.initialized = True
+
+    @classmethod
+    def reset(cls):
+        """used in testing to not leak state between tests"""
+        cls.locales = {}
+        cls.encodings = {}
+        cls.__shared_state = {'current_lang': None}
+        cls.initialized = False
 
     def __init__(self):
+        if not self.initialized:
+            raise Exception("Attempt to use LocaleBorg before initialization")
         self.__dict__ = self.__shared_state
 
+    def set_locale(self, lang):
+        """Sets the locale for language lang, returns ''
+
+        in linux the locale encoding is set to utf8,
+        in windows that cannot be guaranted.
+        In either case, the locale encoding is available in cls.encodings[lang]
+        """
+        # intentional non try-except: templates must ask locales with a lang,
+        # let the code explode here and not hide the point of failure
+        # Also, not guarded with an if lang==current_lang because calendar may
+        # put that out of sync
+        locale_n = self.locales[lang]
+        self.__shared_state['current_lang'] = lang
+        locale.setlocale(locale.LC_ALL, locale_n)
+        return ''
+
+    def get_month_name(self, month_no, lang):
+        """returns localized month name in an unicode string"""
+        if sys.version_info[0] == 3:  # Python 3
+            with calendar.different_locale(self.locales[lang]):
+                s = calendar.month_name[month_no]
+            # for py3 s is unicode
+        else:  # Python 2
+            with calendar.TimeEncoding(self.locales[lang]):
+                s = calendar.month_name[month_no]
+            s = s.decode(self.encodings[lang])
+        # paranoid about calendar ending in the wrong locale (windows)
+        self.set_locale(self.current_lang)
+        return s
+
 
 class ExtendedRSS2(rss.RSS2):
     def publish_extensions(self, handler):
@@ -662,6 +766,25 @@ class ExtendedRSS2(rss.RSS2):
             handler.endElement("atom:link")
 
 
+class ExtendedItem(rss.RSSItem):
+
+    def __init__(self, **kw):
+        author = kw.pop('author')
+        if author and '@' in author[1:]:  # Yes, this is a silly way to validate an email
+            kw['author'] = author
+            self.creator = None
+        else:
+            self.creator = author
+        # It's an old style class
+        return rss.RSSItem.__init__(self, **kw)
+
+    def publish_extensions(self, handler):
+        if self.creator:
+            handler.startElement("dc:creator", {})
+            handler.characters(self.creator)
+            handler.endElement("dc:creator")
+
+
 # \x00 means the "<" was backslash-escaped
 explicit_title_re = re.compile(r'^(.+?)\s*(?<!\x00)<(.*?)>$', re.DOTALL)
 
@@ -685,3 +808,46 @@ def first_line(doc):
             if striped:
                 return striped
     return ''
+
+
+def demote_headers(doc, level=1):
+    """Demote <hN> elements by one."""
+    if level == 0:
+        return doc
+    elif level > 0:
+        r = range(1, 7 - level)
+    elif level < 0:
+        r = range(1 + level, 7)
+    for i in reversed(r):
+        # html headers go to 6, so we can’t “lower” beneath five
+            elements = doc.xpath('//h' + str(i))
+            for e in elements:
+                e.tag = 'h' + str(i + level)
+
+
+def get_root_dir():
+    """Find root directory of nikola installation by looking for conf.py"""
+    root = os.getcwd()
+
+    while True:
+        if os.path.exists(os.path.join(root, 'conf.py')):
+            return root
+        else:
+            basedir = os.path.split(root)[0]
+            # Top directory, already checked
+            if basedir == root:
+                break
+            root = basedir
+
+    return None
+
+
+def get_translation_candidate(config, path, lang):
+    """
+    Return a possible path where we can find the translated version of some page
+    based on the TRANSLATIONS_PATTERN configuration variable
+    """
+    pattern = config['TRANSLATIONS_PATTERN']
+    path, ext = os.path.splitext(path)
+    ext = ext[1:] if len(ext) > 0 else ext
+    return pattern.format(path=path, lang=lang, ext=ext)
