@@ -8,10 +8,16 @@
 
 __all__ = ["BaseTestCase", "cd", "LocaleSupportInTesting"]
 
-from contextlib import contextmanager
-import locale
+
+# This code is so you can run the samples without installing the package,
+# and should be before any import touching nikola, in any file under tests/
 import os
 import sys
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
+
+
+from contextlib import contextmanager
+import locale
 import unittest
 
 import logbook
@@ -106,31 +112,33 @@ class LocaleSupportInTesting(object):
         if hasattr(cls, 'langlocales'):
             return
         defaults = {
-            'linux': {
+            'posix': {
                 # non-windows defaults, must be two locales suported by .travis.yml
                 'default': ("en", str("en_US.utf8")),
-                'other': ("es", str("es_ES.utf8")),
+                'other': ("pl", str("pl_PL.utf8")),
             },
             'windows': {
                 # windows defaults
                 'default': ("en", str("English")),
-                'other': ("es", str("Spanish")),
+                'other': ("pl", str("Polish")),
             },
         }
-        os_id = 'windows' if sys.platform == 'win32' else 'linux'
+        os_id = 'windows' if sys.platform == 'win32' else 'posix'
         langlocales = {}
         for suffix in ['other', 'default']:
             try:
-                s = os.environ['NIKOLA_LOCALE_' + suffix.upper()]
+                envar = 'NIKOLA_LOCALE_' + suffix.upper()
+                s = os.environ[envar]
                 parts = s.split(',')
                 lang = parts[0].strip()
                 try:
                     locale_n = str(parts[1].strip())
-                    locale.setlocale(locale_n)
+                    locale.setlocale(locale.LC_ALL, locale_n)
                 except Exception:
-                    msg = ("Environment variable {0} fails to specify a valid 'lang', 'locale'" +
-                           "Check your sintax, check that python supports that locale in your host")
-                    nikola.utils.LOGGER.error(msg.format(s))
+                    msg = ("Environment variable {0} fails to specify a valid <lang>,<locale>." +
+                           "Check your syntax, check that python supports that locale in your host.")
+                    nikola.utils.LOGGER.error(msg.format(envar))
+                    sys.exit(1)
             except KeyError:
                 lang, locale_n = defaults[os_id][suffix]
             langlocales[suffix] = (lang, locale_n)
