@@ -1,15 +1,22 @@
 # -*- coding: utf-8 -*-
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
-from context import nikola
+# This code is so you can run the samples without installing the package,
+# and should be before any import touching nikola, in any file under tests/
 import os
+import sys
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
+
+
 import unittest
 import mock
 
+import nikola
 import nikola.plugins.command.import_wordpress
+from .base import BaseTestCase
 
 
-class BasicCommandImportWordpress(unittest.TestCase):
+class BasicCommandImportWordpress(BaseTestCase):
     def setUp(self):
         self.module = nikola.plugins.command.import_wordpress
         self.import_command = self.module.CommandImportWordpress()
@@ -155,17 +162,18 @@ class CommandImportWordpressTest(BasicCommandImportWordpress):
                         self.import_command.import_posts(channel)
 
         self.assertTrue(download_mock.called)
+        qpath = 'new_site/files/wp-content/uploads/2008/07/arzt_und_pfusch-sick-cover.png'
         download_mock.assert_any_call(
             'http://some.blog/wp-content/uploads/2008/07/arzt_und_pfusch-sick-cover.png',
-            'new_site/files/wp-content/uploads/2008/07/arzt_und_pfusch-sick-cover.png')
+            qpath.replace('/', os.sep))
 
         self.assertTrue(write_metadata.called)
         write_metadata.assert_any_call(
-            'new_site/stories/kontakt.meta', 'Kontakt',
+            'new_site/stories/kontakt.meta'.replace('/', os.sep), 'Kontakt',
             'kontakt', '2009-07-16 20:20:32', None, [])
 
         self.assertTrue(write_content.called)
-        write_content.assert_any_call('new_site/posts/200704hoert.wp',
+        write_content.assert_any_call('new_site/posts/200704hoert.wp'.replace('/', os.sep),
                                       """An image.
 
 <img class="size-full wp-image-16" title="caption test" src="http://some.blog/wp-content/uploads/2009/07/caption_test.jpg" alt="caption test" width="739" height="517" />
@@ -185,11 +193,11 @@ The end.
 """)
 
         write_content.assert_any_call(
-            'new_site/posts/200807arzt-und-pfusch-s-i-c-k.wp',
+            'new_site/posts/200807arzt-und-pfusch-s-i-c-k.wp'.replace('/', os.sep),
             '''<img class="size-full wp-image-10 alignright" title="Arzt+Pfusch - S.I.C.K." src="http://some.blog/wp-content/uploads/2008/07/arzt_und_pfusch-sick-cover.png" alt="Arzt+Pfusch - S.I.C.K." width="210" height="209" />Arzt+Pfusch - S.I.C.K.Gerade bin ich \xfcber das Album <em>S.I.C.K</em> von <a title="Arzt+Pfusch" href="http://www.arztpfusch.com/" target="_blank">Arzt+Pfusch</a> gestolpert, welches Arzt+Pfusch zum Download f\xfcr lau anbieten. Das Album steht unter einer Creative Commons <a href="http://creativecommons.org/licenses/by-nc-nd/3.0/de/">BY-NC-ND</a>-Lizenz.
 Die Ladung <em>noisebmstupidevildustrial</em> gibts als MP3s mit <a href="http://www.archive.org/download/dmp005/dmp005_64kb_mp3.zip">64kbps</a> und <a href="http://www.archive.org/download/dmp005/dmp005_vbr_mp3.zip">VBR</a>, als Ogg Vorbis und als FLAC (letztere <a href="http://www.archive.org/details/dmp005">hier</a>). <a href="http://www.archive.org/download/dmp005/dmp005-artwork.zip">Artwork</a> und <a href="http://www.archive.org/download/dmp005/dmp005-lyrics.txt">Lyrics</a> gibts nochmal einzeln zum Download.''')
         write_content.assert_any_call(
-            'new_site/stories/kontakt.wp', """<h1>Datenschutz</h1>
+            'new_site/stories/kontakt.wp'.replace('/', os.sep), """<h1>Datenschutz</h1>
 Ich erhebe und speichere automatisch in meine Server Log Files Informationen, die dein Browser an mich \xfcbermittelt. Dies sind:
 
 <ul>
