@@ -1,5 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
+
+# This code is so you can run the samples without installing the package,
+# and should be before any import touching nikola, in any file under tests/
+import os
+import sys
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
+
+
 import codecs
 import shutil
 import tempfile
@@ -11,7 +19,8 @@ from nikola.plugins.compile.markdown import CompileMarkdown
 
 class FakeSite(object):
     config = {
-        "MARKDOWN_EXTENSIONS": ['fenced_code', 'codehilite']
+        "MARKDOWN_EXTENSIONS": ['fenced_code', 'codehilite'],
+        "LOGGING_HANDLERS": {'stderr': {'loglevel': 'WARNING', 'bubble': True}}
     }
 
 
@@ -44,27 +53,6 @@ class CompileMarkdownTests(unittest.TestCase):
         actual_output = self.compile(input_str)
         self.assertEquals(actual_output, '')
 
-    def test_compile_html_heading_tags(self):
-        input_str = '''\
-# header 1
-## header 2
-### header 3
-#### header 4
-##### header 5
-###### header 6
-'''
-        expected_output = '''\
-<h2>header 1</h2>
-<h3>header 2</h3>
-<h4>header 3</h4>
-<h5>header 4</h5>
-<h6>header 5</h6>
-<h7>header 6</h7>
-'''
-
-        actual_output = self.compile(input_str)
-        self.assertEquals(actual_output.strip(), expected_output.strip())
-
     def test_compile_html_code_hilite(self):
         input_str = '''\
     #!python
