@@ -1,19 +1,43 @@
 # -*- coding: utf-8 -*-
 
 from __future__ import unicode_literals, absolute_import
-import unittest
+
+# This code is so you can run the samples without installing the package,
+# and should be before any import touching nikola, in any file under tests/
+import os
+import sys
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
+
+
+from collections import defaultdict
+from io import StringIO
 import os
 import re
-from io import StringIO
+import unittest
 
 import mock
 
-from .context import nikola
 from lxml import etree
+from .base import LocaleSupportInTesting
+
+import nikola
+
+fake_conf = defaultdict(str)
+fake_conf['TIMEZONE'] = 'UTC'
+fake_conf['DEFAULT_LANG'] = 'en'
+fake_conf['TRANSLATIONS'] = {'en': ''}
+fake_conf['BASE_URL'] = 'http://some.blog/'
+
+
+class FakeCompiler(object):
+    demote_headers = False
+    compile_html = None
 
 
 class RSSFeedTest(unittest.TestCase):
     def setUp(self):
+        LocaleSupportInTesting.initialize_locales_for_testing('unilingual')
+
         self.blog_url = "http://some.blog"
 
         with mock.patch('nikola.post.get_meta',
@@ -30,14 +54,12 @@ class RSSFeedTest(unittest.TestCase):
                                 mock.Mock(return_value='some long text')):
 
                     example_post = nikola.nikola.Post('source.file',
-                                                      'cache',
+                                                      fake_conf,
                                                       'blog_folder',
                                                       True,
                                                       {'en': ''},
-                                                      'en',
-                                                      self.blog_url,
-                                                      'unused message.',
-                                                      'post.tmpl')
+                                                      'post.tmpl',
+                                                      FakeCompiler())
 
                     opener_mock = mock.mock_open()
 
