@@ -27,13 +27,18 @@ always unquoted.
 
 from __future__ import unicode_literals, absolute_import
 
+# This code is so you can run the samples without installing the package,
+# and should be before any import touching nikola, in any file under tests/
+import os
+import sys
+sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..'))
+
+
 import codecs
 try:
     from io import StringIO
 except ImportError:
     from StringIO import StringIO  # NOQA
-import os
-import sys
 import tempfile
 
 import docutils
@@ -48,7 +53,7 @@ from nikola.plugins.compile.rest import gist
 from nikola.plugins.compile.rest import vimeo
 import nikola.plugins.compile.rest.listing
 from nikola.plugins.compile.rest.doc import Plugin as DocPlugin
-from nikola.utils import _reload
+from nikola.utils import _reload, STDERR_HANDLER
 from nikola.plugin_categories import (
     Command,
     Task,
@@ -96,6 +101,7 @@ class FakeSite(object):
             "TaskMultiplier": TaskMultiplier,
             "RestExtension": RestExtension,
         })
+        self.loghandlers = [STDERR_HANDLER]
         self.plugin_manager.setPluginInfoExtension('plugin')
         if sys.version_info[0] == 3:
             places = [
@@ -112,6 +118,7 @@ class FakeSite(object):
             FakePost(title='Fake post',
                      slug='fake-post')
         ]
+        self.debug = True
 
     def render_template(self, name, _, context):
         return('<img src="IMG.jpg">')
